@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 1998, 1999, 2000, 2001
+ * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2006
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
@@ -43,7 +43,10 @@ typedef	struct {
 	int ioflags;			/* flags of xxxx_first() */
 	char *lastdat;			/* the data of last located record */
 	int lastsize;			/* the size of the lastdat */
+	char *lastkey;			/* the key of last located record */
+	int lastkeysize;		/* the size of the key */
 	regex_t	*preg;			/* compiled regular expression */
+	int unread;			/* leave record to read again */
 	/*
 	 * (2) DB185 PART
 	 */
@@ -74,6 +77,7 @@ void dbop_delete(DBOP *, const char *);
 void dbop_update(DBOP *, const char *, const char *);
 const char *dbop_first(DBOP *, const char *, regex_t *, int);
 const char *dbop_next(DBOP *);
+void dbop_unread(DBOP *);
 const char *dbop_lastdat(DBOP *, int *);
 const char *dbop_getflag(DBOP *);
 const char *dbop_getoption(DBOP *, const char *);
